import { useState, useEffect } from "react";
import Taro from "@tarojs/taro";
import withLayout from "@/layout";
import { ScrollView, Image, RichText } from "@tarojs/components";
import Disclaimer from "@/components/Disclaimer";

import {
  // addActivityShareNum,
  signupActivity,
  queryActivityDetail,
} from "@/services/activity";
import { getImgURL } from "@/utils/image";
import getDateFormat from "@/utils/chatDate";
import useParams from "@/utils/hooks/useParams";
import useShare from "@/utils/hooks/useShare";
import useFavor from "@/utils/hooks/useFavor";

import "./index.scss";

const activityStatusDict = {
  0: {
    text: "立即参与",
    text1: "立即参团",
    className: "yellow",
  },
  1: {
    text: "未开始",
    text1: "未开始",
    className: "blue",
  },
  2: {
    text: "已结束",
    text1: "已结束",
    className: "grey",
  },
  3: {
    text: "已参与",
    text1: "已结束",
    className: "yellow",
  },
};

export default withLayout((props) => {
  const { router, shareContent, trackData, person, page } = props;
  const { id } = router.params;
  const [detail, setDetail] = useState();
  const buildingId = detail?.buildingId;

  const getDetail = (params) => {
    Taro.showLoading();

    queryActivityDetail(params).then((res) => {
      console.log(res, "queryActivityDetail");
      setDetail(res);

      Taro.hideLoading();
    });
  };

  // 本页面分享或者海报参数
  const paramsRef = useParams({
    id,
    buildingId,
    person,
    from: `${page.type}_share`,
  });

  const fullTrackData = { ...trackData, buildingId };

  const [isSaved, handleFavor] = useFavor(detail?.isSaved, {
    id,
    buildingId,
    ...trackData,
  });

  useShare(
    {
      title: shareContent.shareContentTitle || detail?.title,
      path: `${router.path}?${paramsRef.current}`,
      image: shareContent.shareContentImg || getImgURL(detail?.imgUrl),
    },
    fullTrackData
  );

  useEffect(() => {
    if (id) {
      getDetail(id);
    }
  }, [id]);

  const handleSignup = () => {
    const {
      detail: { buildingId, dynamicId, isSign },
    } = this.state;
    const {
      userInfo: {
        person: { phone, name, nickname },
      },
    } = this.props;

    if (isSign) {
      Taro.showToast({
        icon: "none",
        title: "你已报名成功",
      });
      return;
    }

    this.setState({
      canChoose: "block",
    });
  };

  const dymic = () => (
    <view className="Info">
      <view>
        <view className="Title flex-h">
          <view className="flex-item">
            <text>{detail.halfTitle}</text>
          </view>
          <text className="Tips">{detail.enlisted || 0}人已报名</text>
        </view>
        <text className="Time">
          报名截止时间：
          {getDateFormat(
            new Date(detail.enlistEnd).valueOf(),
            true,
            "yyyy/M/d"
          )}
        </text>
        <text className="Name">{detail.title}</text>
        <view className="flex-h Address">
          <text>地址：</text>
          <view className="flex-item">
            <text>{detail.address}</text>
          </view>
        </view>
        <view className="flex-h Date">
          <text>时间：</text>
          <view className="flex-item">
            <text>
              {getDateFormat(
                new Date(detail.startDate).valueOf(),
                true,
                "yyyy/M/d"
              )}{" "}
              -{" "}
              {getDateFormat(
                new Date(detail.endDate).valueOf(),
                true,
                "yyyy/M/d"
              )}
            </text>
          </view>
        </view>
        <view className="Btn">
          <button open-type="share">
            <text>分享好友</text>
          </button>
        </view>
      </view>
    </view>
  );

  const house = () => (
    <view className="houseInfo">
      {/* <view> */}
      <view className="flex-h">
        <view className="left">
          <view className="Title">
            <view className="flex-item">
              <text>{detail.title}</text>
            </view>
          </view>
          <view className="flex-h Address">
            <text className="iconfont icon-dingwei"></text>
            <view className="flex-item">
              <text>{detail.address}</text>
            </view>
            <text className="price">价格待定</text>
          </view>
          <text className="flex-h Time">
            时间：
            {getDateFormat(
              new Date(detail.startDate).valueOf(),
              true,
              "yyyy/M/d"
            )}{" "}
            -{" "}
            {getDateFormat(
              new Date(detail.endDate).valueOf(),
              true,
              "yyyy/M/d"
            )}
          </text>
        </view>
        <view className="right">
          <view>
            <button  open-type="share">
              <text className="iconfont icon-fenxiang"></text>
              <text>分享</text>
            </button>
            {/* <text className="iconfont icon-dingwei"></text>
            <text>分享</text> */}
          </view>
          <view>
            <text className="iconfont icon-dingwei"></text>
            <text>海报</text>
          </view>
        </view>
      </view>

      <view className="lastdate">
        <text className="text">距离结束还有</text>
        <text className="text day">7</text>
        <text className="text">天</text>
        <text className="text time">2</text>
        <text className="text">时</text>
        <text className="text time">4</text>
        <text className="text">分</text>
        <text className="text time">5</text>
        <text className="text">秒</text>
        {/* <view>距离结束还有</view> */}
      </view>

      <view className="flex-h join">
        <view className="Collect" onClick={handleFavor}>
          <text
            className="iconfont icon-shoucang"
            style={isSaved ? { color: "red" } : undefined}
          ></text>
          <text>{isSaved ? "已收藏" : "收藏"}</text>
        </view>
        <view className="enlisted">
          <view>
            <text className="iconfont icon-shoucang"></text>
            <text>{detail.enlisted || 0}人已报名</text>
          </view>
        </view>
        <view className="btn" onClick={handleSignup}>
          <text>{activityStatusDict[detail.activityStatus]?.text1}</text>
        </view>
      </view>
      {/* </view> */}
    </view>
  );

  return (
    <>
      {detail && (
        <view className="Page activityDetail flex-v">
          <view className="flex-item">
            <view>
              <ScrollView scroll-y>
                <view className="PageContent">
                  <view className="Top">
                    <Image
                      mode="aspectFill"
                      src={getImgURL(detail.bannerListImg)}
                      className="centerLabel"
                    ></Image>
                  </view>

                  {detail.type == "dymic" && dymic()}
                  {detail.type == "house" && house()}
                  <view className="ActivityIntro">
                    <view className="Title">
                      <text>活动介绍</text>
                    </view>
                    <RichText nodes={detail.desc} />
                  </view>

                  <Disclaimer />
                </view>
              </ScrollView>
            </view>
          </view>
          {detail.type == "dymic" && (
            <view className="PageBottom flex-h">
              <button className="Share" open-type="share">
                <text className="iconfont icon-fenxiang"></text>
                <text>分享</text>
              </button>
              <view className="Collect" onClick={handleFavor}>
                <text
                  className="iconfont icon-shoucang"
                  style={isSaved ? { color: "red" } : undefined}
                ></text>
                <text>{isSaved ? "已收藏" : "收藏"}</text>
              </view>
              <view className="flex-item"></view>

              <text className="Post" onClick={handleSignup}>
                {activityStatusDict[detail.activityStatus]?.text}
              </text>
            </view>
          )}
        </view>
      )}
    </>
  );
});
